<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Затвори (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Колапс</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Прошири</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Одбаци упозорење</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln реч</numerusform>
            <numerusform>%Ln речи</numerusform>
            <numerusform>%Ln речи</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln минут</numerusform>
            <numerusform>%Ln минута</numerusform>
            <numerusform>%Ln минути</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% од %Ln минута</numerusform>
            <numerusform>%L1% од %Ln минута</numerusform>
            <numerusform>%L1% од %Ln минута</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% од %Ln речи</numerusform>
            <numerusform>%L1% од %Ln речи</numerusform>
            <numerusform>%L1% од %Ln речи</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Дневни напредак</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Најдужа серија</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Тренутна серија</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n дан</numerusform>
            <numerusform>%n дана</numerusform>
            <numerusform>%n дана</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% од дневног циља</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Подеси језик</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Без наслова %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Само за читање)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Онемогућено чување &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Сачувај фајл као</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Онемогућено да пребрише &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Преименуј фајл</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Онемогућено преименовање &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Поново учитај фајл?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Поново учитај фајл &apos;%1&apos; са диска?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Све несачуване промене ће бити изгубљене.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Поново учитај</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Без наслова %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Питање</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Чување као обичан текст ће одбацити сва обликовања. Одбаци обликовање?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Промењен фајл</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Фајл &apos;%1&apos; је промењен од стране другог програма.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Да ли желите да поново учитате фајл?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Поново учитај</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Занемари</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Обрисан фајл</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Фајл %1 је обрисао други програм.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Да ли желите да сачувате или затворите фајл?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Онемогућено отварање архиве.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Претрага за:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Замени са:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Игнориши случај</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Само целе речи</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Регуларни изрази</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Претражи горе</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Претражи доле</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Пронађи</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Замени</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Замени &amp;све</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Пронађи</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Замени</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Замените %n пример?</numerusform>
            <numerusform>Замените %n примера?</numerusform>
            <numerusform>Замените %n примера?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Питање</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Фраза није пронађена.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Text</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Формат обогаћеног текста</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Чисти текст</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Сви фајлови</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Сви подржани фајлови</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Додај</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Провери правопис...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Без пронађене сугестије)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Отвори слику</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Слике</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Одабери језик програма:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Системски језик&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Напомена</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Молимо рестартујте програм да би се видела промена језика.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Онемогућено отварање архиве.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Опште</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Трака алата</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Провера правописа</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Одабери речник</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Онемогућено отварање архиве.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Архива не садржи уобичајен речник.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Питање</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Пречице</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Један или више кофликт пречица. Да ли желите да наставите?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Речник &quot;%1&quot; већ постоји. Да ли желите да га замените?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Дневни циљ</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ниједан</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Минути:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Речи:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Измене</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Увек вертикални центар</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Блокирај уметање курсора</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Умекшај фонтове</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Звук писаће машине</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Паметни цитати:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Дупли</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Једини</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Сцене</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Разделник:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Чување</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Запамти позицију курсора</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Број речи</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Број страна</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Број параграфа</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Број карактера</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Карактери:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Параграфи:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Број алторитама</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Врати дневни напредак за данас на нулу?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Напиши бајт редослед ознака у текстуалном фајлу</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Подразумевани формат:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Врати данас на почетно</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Историја</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Запамти историју</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Покажи серије</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Минимум напретка за серије:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Детектовање границе речи</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Подели број карактера са шест</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Рачунај свако слово као реч</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Број страна алгоритама</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Изглед</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Само иконе</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Само текст</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Текст поред икона</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Текст испод икона</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Позиција текста:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Акције</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Помери горе</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Помери доле</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Додај раздвајач</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Команда</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Пречица</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Акција</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Проверите правопис док куцате</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Занемари речи са ВЕЛИКИМ СЛОВИМА</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Занемари речи са бројевима</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Језик</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додај</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Уклони</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Лични речник</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Није подржан RTF фајл.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Неочекивано стигао крај фајла.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Помери сцене горе</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Укључи/искључи листу сцена</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Покажи листу сцена (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Сакриј листу сцена (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Филтер</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Помери сцене доле</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Промени величину листе сцена</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Подразумевано</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Управљај сесијама</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>С&amp;есије</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Нови</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Дупликат</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуј</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Избриши</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Пребаци на</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Нова сесија</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Дупликат сесија</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Преименуј сесију</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Питање</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Избриши одабрану сесију?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Име сесије:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Захтевано име сесије је већ у употреби.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Нова...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Управљај...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Очисти</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Ресетуј на подразумевано</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Пречица:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Замена наводника...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Молимо сачекајте</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Провери правопис</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Додај</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Занемари</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>З&amp;анемари све</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Промени</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>П&amp;ромени све</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Није у речнику:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Промени на:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Провери правопис...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Молимо сачекајте</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Наставите проверу на почетку фајла?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Провера правописа је завршена.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Симболи</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Недавно коришћени симболи</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Сви симболи</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детаљи</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Име:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Инсерт</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Блокови</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Скрипте</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Без наслова %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Име:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Без слике</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Поплочано</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Центрирано</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Раширено</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Скалирано</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Зумирано</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Непрозирност:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Позиција:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Заокружи углове позадине текста</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Радијус:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Замути позадину текста</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Осенчи позадину текста</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Вертикално:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Ивице:</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Прозор:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Страна:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Увлачење прве линије</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Изнад:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Испод:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Уклони</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Измени тему</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Позадина прозора</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Врста:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Боја:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Слика:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>пиксела</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Лево</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Позадина текста</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Десно</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Фонт:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Погрешно написано:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Проред</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Један</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 линија</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Дупли</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Пропорционалан</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Висина:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Пасус</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Ширина картице:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Нова тема</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Теме</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Подразумевано</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Блуз</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Стара школа</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Свемирски снови</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Писаћи сто</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Нови</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Дупликат</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Прилагођено</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Измени</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Избриши</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Увези</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Извези</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Питање</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Подразумевана тема &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Теме (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Увези тему</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Извези тему</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Питање</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Обриши тајмер?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Речи:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Стране:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Параграфи:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Карактери:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Подеси кашњење</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Подеси време</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Кашњење:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Време:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Аларм</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Врста:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Меморандум:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Измени</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Избриши</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Без покренутог тајмера</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Тајмери</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Нови</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Скорашње</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Питање</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Откажи измене тајмера?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Учитавање тема</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Учитавање звука</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Без наслова</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Отвори фајл</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>О програму FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Једноставан обрађивач текста на пуном екрану</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Реализовано под &lt;a href=%1&gt;GPL 3&lt;/a&gt; лиценцом</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Користи иконе из &lt;a href=%1&gt;Oxygen&lt;/a&gt; теме икона</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Коришћен под &lt;a href=%1&gt;LGPL 3&lt;/a&gt; лиценцом</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Карактери: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Стране: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Параграфи: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Речи: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Oтварање %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Без наслова %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Листа свих докумената</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Пређи на следећи документ</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Пређи на претходни документ</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Пређи на први документ</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Пређи на последњи документ</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Пређи на документ %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Учитавање подешавања</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Ургентни кеш није уписив.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter није затворен чисто.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Враћање из ургентног кеша?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Неки фајлови нису могли бити отворени.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Неки фајлови су отворени само за читање.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; је новије од кеширане копије.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Пребиши новији фајл?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Сачувај промене?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Сачувајте промене фајла &apos;%1&apos; пре затварања?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Ваше промене ће бити изгубљене, ако их не сачувате.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Онемогућено учитавање звука писаће машине.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Фајл</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Нови</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Отвори...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Поно&amp;во учитај</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Сачувај</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Сачувај &amp;као...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Преименуј...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Сачувај с&amp;ве</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Управљај сесијама</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Нова сесија</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Штампај...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Затвори</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Напусти</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Измени</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Опозови</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Поново уради</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Исе&amp;ци</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копирај</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Налепи</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Налепи &amp;неформатирано</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Одабери &amp;све</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Одабери &amp;сцену</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Фо&amp;рмат</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Подебљано</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Искошено</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Подвучено</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Пре&amp;цртано</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Екс&amp;понент</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Индекс</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Поравнај &amp;лево</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Поравнај &amp;на центар</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Поравнај &amp;десно</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Поравнај &amp;обострано</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Смањи увлачење</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>П&amp;овећај увлачење</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Ле&amp;во на десно блок</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Де&amp;сно на лево блок</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Алати</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Пронађи...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Пронађи &amp;следеће</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Пронађи пре&amp;тходно</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Замени...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Паметни &amp;цитати</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Ажурирај &amp;документ</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Ажурирај &amp;одабир</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Правопис...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Подеси &amp;језик...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Tајмери...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>С&amp;имболи...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Дневни напредак</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Подешавање</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Покажи &amp;траку алата</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Покажи &amp;иконе менија</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Ф&amp;окусирани текст</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Пун екран</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;инимизуј</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Tеме...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Подешавања...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Фокусирање искључено</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Фокусирање једне линије</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Фокусирање три линије</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Параграф</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Фокусирај параграф</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помоћ</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Језик &amp;програма...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Неки фајлови нису подржани и не могу бити отворени.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Искључено</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Једна &amp;линија</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Три линије</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О програму</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Наслов</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Наслов &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Наслов &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Наслов &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Наслов &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Наслов &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Наслов &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Стандардно</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
